@@ -438,7 +438,7 @@ typedef struct _rx_ring_t
     /**************************************************************************
        lookaside lists
      *************************************************************************/
-    kmem_cache_t             *RecvLookaside;
+    struct kmem_cache        *RecvLookaside;
 }
 RX_RING_t, *PRX_RING_t;
 
