@@ -458,7 +458,7 @@ int et131x_open( struct net_device *netdev )
      *************************************************************************/
     DBG_TRACE( et131x_dbginfo, "Registering ISR...\n" );
 
-    result = request_irq( netdev->irq, et131x_isr, SA_SHIRQ, netdev->name, netdev );
+    result = request_irq( netdev->irq, et131x_isr, IRQF_SHARED, netdev->name, netdev );
     if( result )
     {
         DBG_ERROR( et131x_dbginfo, "Could not register ISR\n" );
@@ -690,7 +690,7 @@ int et131x_ioctl( struct net_device *netdev, struct ifreq *reqbuf, int cmd )
         break;
 	
     default:
-        DBG_WARNING( et131x_dbginfo, "Unhandled IOCTL Code: 0x%04x\n", cmd );
+/*        DBG_WARNING( et131x_dbginfo, "Unhandled IOCTL Code: 0x%04x\n", cmd );*/
 		status = -EOPNOTSUPP;
 	}
 
@@ -1147,6 +1147,8 @@ void et131x_tx_timeout( struct net_device *netdev )
             DumpDeviceBlock( DBG_WARNING_ON, pAdapter, 3 );
             DumpDeviceBlock( DBG_WARNING_ON, pAdapter, 5 );
 #endif
+            et131x_close( netdev );
+            et131x_open( netdev );
 
             return;
         }
@@ -1328,14 +1330,15 @@ int et131x_change_mtu( struct net_device *netdev, int new_mtu )
  *****************************************************************************/
 int et131x_set_mac_addr( struct net_device *netdev, void *new_mac )
 {
+    int             result = 0;
+    ET131X_ADAPTER *adapter = NULL;
+    struct sockaddr *address = new_mac;
+
     DBG_FUNC( "et131x_set_mac_addr" );
     DBG_ENTER( et131x_dbginfo );
     // begin blux
     // DBG_VERBOSE( et131x_dbginfo, "Function not implemented!!\n" );
 
-    int             result = 0;
-    ET131X_ADAPTER *adapter = NULL;
-    struct sockaddr *address = new_mac;
     /*-----------------------------------------------------------------------*/
 
 
@@ -1602,7 +1605,7 @@ void et131x_vlan_rx_kill_vid( struct net_device *netdev, UINT16 vid )
 
     if( pAdapter->vlgrp )
     {
-        pAdapter->vlgrp->vlan_devices[vid] = NULL;
+        pAdapter->vlgrp->vlan_devices_arrays[vid] = NULL;    
     }
 
 
